@@ -552,7 +552,7 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 		}
 	}
 		
-	strcpy (pAccessMethod->DisplayName, _((gchar *)pStringAttributeValue));
+	pAccessMethod->DisplayName = g_strdup (_((gchar *)pStringAttributeValue));
 
 	/* read the UI for the access method */
 	gok_scanner_read_description (pDoc, pNodeAccessmethod->xmlChildrenNode, pAccessMethod);
@@ -601,8 +601,7 @@ gboolean gok_scanner_read_access_method (gchar* Filename)
 			pStringStateId = xmlGetProp (pNodeState, (const xmlChar *) "name");
 			if (pStringStateId != NULL)
 			{
-				pState->NameState = (gchar*)g_malloc (strlen ((gchar *)pStringStateId) + 1);
-				strcpy (pState->NameState, (gchar *)pStringStateId);
+				pState->NameState = g_strdup ((gchar *)pStringStateId);
 			}
 
 			/* get the initialization for the state */
@@ -795,8 +794,7 @@ GokScannerHandler* gok_scanner_construct_handler (gchar* pHandlerName)
 	}
 	else
 	{
-		pHandler->EffectName = (gchar*)g_malloc (strlen (pHandlerName) + 1);
-		strcpy (pHandler->EffectName, pHandlerName);
+		pHandler->EffectName = g_strdup (pHandlerName);
 	}	
 	
 	return pHandler;
@@ -935,13 +933,11 @@ gboolean gok_scanner_read_rates (xmlNode* pNode, GokAccessMethod* pAccessMethod)
 				pRateLast = pRate;
 
 				/* populate the rate structure */
-				pRate->Name = (gchar*)g_malloc (strlen ((gchar *)pStringName) + 1);
-				strcpy (pRate->Name, (gchar *)pStringName);
+				pRate->Name = g_strdup ((gchar *)pStringName);
 							
 				if (pStringValue != NULL)
 				{
-					pRate->StringValue = (gchar*)g_malloc (strlen ((gchar *)pStringValue) + 1);
-					strcpy (pRate->StringValue, (gchar *)pStringValue);
+					pRate->StringValue = g_strdup ((gchar *)pStringValue);
 				}
 
 				if (pValueAsString != NULL)
@@ -1085,8 +1081,7 @@ void gok_scanner_read_ui_loop (GokControl* pControl, xmlNode* pNode)
 			pStringAttributeValue = xmlGetProp (pNode, (const xmlChar *) "name");
 			if (pStringAttributeValue != NULL)
 			{
-				pControlNew->Name = (gchar*)g_malloc (strlen ((gchar *)pStringAttributeValue) + 1);
-				strcpy (pControlNew->Name, (gchar *)pStringAttributeValue);
+				pControlNew->Name = g_strdup ((gchar *)pStringAttributeValue);
 			}
 			xmlFree (pStringAttributeValue);
 			
@@ -1114,8 +1109,7 @@ void gok_scanner_read_ui_loop (GokControl* pControl, xmlNode* pNode)
 			pStringAttributeValue = xmlGetProp (pNode, (const xmlChar *) "string");
 			if (pStringAttributeValue != NULL)
 			{
-				pControlNew->String = (gchar*)g_malloc (strlen ((gchar *)pStringAttributeValue) + 1);
-				strcpy (pControlNew->String, (gchar *)pStringAttributeValue);
+				pControlNew->String = g_strdup ((gchar *)pStringAttributeValue);
 			}
 			xmlFree (pStringAttributeValue);
 			
@@ -1204,8 +1198,7 @@ void gok_scanner_read_ui_loop (GokControl* pControl, xmlNode* pNode)
 			pStringAttributeValue = xmlGetProp (pNode, (const xmlChar *) "associated");
 			if (pStringAttributeValue != NULL)
 			{
-				pControlNew->NameAssociatedControl = (gchar*)g_malloc (strlen ((gchar *)pStringAttributeValue) + 1);
-				strcpy (pControlNew->NameAssociatedControl, (gchar *)pStringAttributeValue);
+				pControlNew->NameAssociatedControl = g_strdup ((gchar *)pStringAttributeValue);
 			}
                         xmlFree (pStringAttributeValue);
 
@@ -1373,7 +1366,7 @@ GokScannerEffect* gok_scanner_read_effects (xmlNode* pNodeGiven, GokAccessMethod
 						pStringAttributeValue = xmlGetProp (pNodeEffect, (const xmlChar *) "param1");
 						if (pStringAttributeValue != NULL)
 						{
-							Param1 = (char *)pStringAttributeValue;
+							Param1 = g_strdup ((gchar *)pStringAttributeValue);
 						}
 						xmlFree (pStringAttributeValue);
 
@@ -1381,7 +1374,7 @@ GokScannerEffect* gok_scanner_read_effects (xmlNode* pNodeGiven, GokAccessMethod
 						pStringAttributeValue = xmlGetProp (pNodeEffect, (const xmlChar *) "param2");
 						if (pStringAttributeValue != NULL)
 						{
-							Param2 = (char *)pStringAttributeValue;
+							Param2 = g_strdup ((gchar *)pStringAttributeValue);
 						}
 						xmlFree (pStringAttributeValue);
 
@@ -1392,7 +1385,7 @@ GokScannerEffect* gok_scanner_read_effects (xmlNode* pNodeGiven, GokAccessMethod
 						pStringAttributeValue = xmlGetProp (pNodeEffect, (const xmlChar *) "name");
 						if (pStringAttributeValue != NULL)
 						{
-if (gok_data_get_setting (pAccessMethod->Name, pStringAttributeValue, NULL, &pName) == FALSE)
+						    if (gok_data_get_setting (pAccessMethod->Name, pStringAttributeValue, NULL, &pName) == FALSE)
 								pName = pStringAttributeValue;
 						}
 #endif
@@ -1493,7 +1486,7 @@ if (gok_data_get_setting (pAccessMethod->Name, pStringAttributeValue, NULL, &pNa
 															pEffectTrue,
 															pEffectFalse,
 															pName);
-						xmlFree (pName);
+						g_free (pName);
 
 						/* add the effect to our list of effects */
 						if (pEffectFirst == NULL)
@@ -1560,8 +1553,7 @@ GokScannerEffect* gok_scanner_create_effect (gint CallId, gchar* Param1, gchar*
 	}
 	else
 	{
-		pEffectNew->pName = (gchar*) g_malloc (strlen (pName) + 1);
-		strcpy (pEffectNew->pName, pName);
+		pEffectNew->pName = g_strdup (pName);
 	}
 	
 	if (Param1 == NULL)
@@ -1570,8 +1562,7 @@ GokScannerEffect* gok_scanner_create_effect (gint CallId, gchar* Param1, gchar*
 	}
 	else
 	{
-		pEffectNew->CallParam1 = (gchar*) g_malloc (strlen (Param1) + 1);
-		strcpy (pEffectNew->CallParam1, Param1);
+		pEffectNew->CallParam1 = g_strdup (Param1);
 	}
 
 	if (Param2 == NULL)
@@ -1580,8 +1571,7 @@ GokScannerEffect* gok_scanner_create_effect (gint CallId, gchar* Param1, gchar*
 	}
 	else
 	{
-		pEffectNew->CallParam2 = (gchar*) g_malloc (strlen (Param2) + 1);
-		strcpy (pEffectNew->CallParam2, Param2);
+		pEffectNew->CallParam2 = g_strdup (Param2);
 	}
 
 	return pEffectNew;
@@ -1604,6 +1594,8 @@ GokAccessMethod* gok_scanner_create_access_method (gchar* Name)
 	pAccessMethod = (GokAccessMethod*) g_malloc(sizeof(GokAccessMethod));
 
 	/* initialize all the member variables */
+	pAccessMethod->Name = g_strdup (Name);
+	pAccessMethod->DisplayName = NULL;
 	pAccessMethod->pStateFirst = NULL;
 	pAccessMethod->pAccessMethodNext = NULL;
 	pAccessMethod->pInitializationEffects = NULL;
@@ -1613,9 +1605,6 @@ GokAccessMethod* gok_scanner_create_access_method (gchar* Name)
 	pAccessMethod->pControlFeedback = NULL;
 	pAccessMethod->pControlOptions = NULL;
 
-	/* set the name of the access method */
-	strncpy (pAccessMethod->Name, Name, MAX_ACCESS_METHOD_NAME);
-
 	/* add it to the list of access methods */
 	/* add it at the start if the start hasn't been set */
 	if (m_pAccessMethodFirst == NULL)
@@ -1711,6 +1700,10 @@ void gok_scanner_close()
 
 			g_free (pRateTemp);
 		}
+		
+		/* Delete names */
+		g_free (pAccessMethod->Name);
+		g_free (pAccessMethod->DisplayName);
 
 		/* delete the access method */
 		pAccessMethodTemp = pAccessMethod;
@@ -2737,7 +2730,7 @@ void gok_scanner_perform_effects (GokScannerEffect* pEffect)
 				break;
 
 			case CALL_CHUNKER_MOVE_LEFTRIGHT:
-gok_log_x ("chunker move leftright\n");
+				gok_log_x ("chunker move leftright\n");
 				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
 											&rate, NULL) == TRUE)
 				{
@@ -2750,7 +2743,7 @@ gok_log_x ("chunker move leftright\n");
 				break;
 
 			case CALL_CHUNKER_MOVE_TOPBOTTOM:
-gok_log_x ("chunker move topbottom\n");
+				gok_log_x ("chunker move topbottom\n");
 				if (gok_data_get_setting (pAccessMethod->Name, pEffect->pName, 
 											&rate, NULL) == TRUE)
 				{
@@ -3283,8 +3276,7 @@ if (pRate->StringValue != NULL)
 				}
 				else
 				{
-					pRate->StringValue = (gchar*)g_malloc (strlen (pValueStringNew) + 1);
-					strcpy (pRate->StringValue, pValueStringNew);
+					pRate->StringValue = g_strdup (pValueStringNew);
 				}
 			}
 			else
@@ -3370,7 +3362,21 @@ gok_scanner_current_state_uses_corepointer (void)
 				      GOK_GCONF_INPUT_DEVICE, 
 				      &input_device_name);
 
-		if (input_device_name == NULL)
+		/* IGNORE potential corepointer effects if we're using
+		 * direct selection and there is no specified XInput device;
+		 * since arguably it's worse to detach the corepointer
+		 * that just to allow the resulting bugs.
+		 * We make this determination because this is the default
+		 * config and thus the initial out-of-the-box experience
+		 * for GOK, and we don't want to alarm users, testers,
+		 * or distros by spewing dire warnings.  Besides, most
+		 * direct selection users will be able to work around
+		 * the corepointer-grab bugs, and the warnings
+		 * are still present in Help and the GOK docs, for those
+		 * few direct-selection users who may experience trouble
+		 * as a result of our suppressing the corepointer-detach.
+		 */
+		if ((input_device_name == NULL) && (strcmp (gok_data_get_name_accessmethod (), "directselection")))
 			retval = TRUE;
 		else
 			g_free (input_device_name);
@@ -3444,17 +3450,18 @@ gok_scanner_current_state_uses_core_mouse_button(int button)
 gint gok_scanner_make_type_from_string (gchar* pString)
 {
 	gint codeReturned;
+	gchar** tokens;
 	gchar* pToken;
-	gchar buffer[150];
+	gint i;
 	
 	g_assert (pString != NULL);
 	g_assert (strlen (pString) < 150 );
 
 	codeReturned = 0;
-	strcpy (buffer, pString);
-	pToken = strtok (buffer, "+");
-	while (pToken != NULL)
+	tokens = g_strsplit (pString, "+", 0);
+	for (i = 0; tokens [i] != NULL; i++)
 	{
+		pToken = tokens[i];
 		if (strcmp (pToken, "switch") == 0)
 		{
 			codeReturned |= ACTION_TYPE_SWITCH;
@@ -3471,10 +3478,10 @@ gint gok_scanner_make_type_from_string (gchar* pString)
 		{
 			codeReturned |= ACTION_TYPE_DWELL;
 		}
-				
-		pToken = strtok (NULL, "+");
 	}
 	
+	g_strfreev (tokens);
+	
 	return codeReturned;
 }
 
@@ -3493,8 +3500,8 @@ gboolean gok_scanner_get_multiple_rates (gchar* NameAccessMethod, gchar* NameSet
 {
 	gint rate;
 	gint rateTotal;
-	gchar* pToken;
-	gchar buffer[150];
+	gchar** tokens;
+	int i;
 	
 	g_assert (NameAccessMethod != NULL);
 	g_assert (NameSettings != NULL);
@@ -3503,20 +3510,17 @@ gboolean gok_scanner_get_multiple_rates (gchar* NameAccessMethod, gchar* NameSet
 	rateTotal = 0;
 	*Value = 0;
 
-	strcpy (buffer, NameSettings);
-	pToken = strtok (buffer, "+");
-	while (pToken != NULL)
+	tokens = g_strsplit (NameSettings, "+", 0);
+	for (i = 0; tokens [i] != NULL; i++)
 	{
-		if (gok_data_get_setting (NameAccessMethod, pToken, &rate, NULL) == FALSE)
+		if (gok_data_get_setting (NameAccessMethod, tokens [i], &rate, NULL) == FALSE)
 		{
 			*Value = rateTotal;
 			return FALSE;
 		}
-		rateTotal += rate;
-				
-		pToken = strtok (NULL, "+");
+		rateTotal += rate;				
 	}
-	
+	g_strfreev (tokens);	
 	*Value = rateTotal;
 	
 	return TRUE;
