@@ -34,6 +34,7 @@ extern "C" {
 typedef enum {
 CALL_CHUNKER_RESET,
 CALL_CHUNKER_CHUNK_NONE,
+CALL_CHUNKER_CHUNK_KEYS,
 CALL_CHUNKER_CHUNK_ROWS,
 CALL_CHUNKER_CHUNK_COLUMNS,
 CALL_CHUNKER_NEXT_CHUNK,
@@ -109,9 +110,6 @@ RATE_TYPE_UNDEFINED,
 RATE_TYPE_EFFECT
 } RateType;
 
-/* maximum length of access method name */
-#define MAX_ACCESS_METHOD_NAME 50
-
 /* maximum length of the description of the access method */
 #define MAX_DESCRIPTION_TEXT 200
 
@@ -174,8 +172,8 @@ typedef struct GokScannerState {
 /* an access method (e.g. Inverse Scanning) */
 /* if you add members to this structure, initialize them in gok_scanner_create_access_method */
 typedef struct GokAccessMethod {
-	gchar Name [MAX_ACCESS_METHOD_NAME + 1];
-	gchar DisplayName [MAX_ACCESS_METHOD_NAME + 1];
+	gchar* Name;
+	gchar* DisplayName;
 	gchar Description [MAX_DESCRIPTION_TEXT + 1];
 	GokScannerState* pStateFirst;
 	GokScannerEffect* pInitializationEffects;
@@ -188,7 +186,7 @@ typedef struct GokAccessMethod {
 } GokAccessMethod;
 
 /* functions */
-gboolean gok_scanner_initialize (const gchar *directory);
+gboolean gok_scanner_initialize (const gchar *directory, const gchar *accessmethod, const gchar *selectaction, const gchar *scanaction);
 void gok_scanner_close (void);
 void gok_scanner_stop (void);
 void gok_scanner_start (void);
@@ -220,6 +218,7 @@ GokAccessMethod* gok_scanner_get_current_access_method (void);
 GokAccessMethod* gok_scanner_get_first_access_method (void);
 GokScannerState* gok_scanner_get_current_state (void);
 gboolean gok_scanner_current_state_uses_core_mouse_button(int button);
+gboolean gok_scanner_current_state_uses_corepointer (void);
 void gok_scanner_get_pointer_location (gint* pX, gint* pY);
 gint gok_scanner_timer_set (gint Rate, gint ID);
 gint gok_scanner_timer_stop (gint TimerId);
